<?php
date_default_timezone_set("Asia/Ho_Chi_Minh");
// Đường dẫn đến tệp cơ sở dữ liệu SQLite3
define('DB_PATH', 'usage_log.db');

// Tạo bảng nếu chưa tồn tại
function initializeDatabase() {
    $db = new SQLite3(DB_PATH);
    
    // Kiểm tra nếu kết nối thành công
    if (!$db) {
        die("Lỗi khi kết nối cơ sở dữ liệu: " . $db->lastErrorMsg());
    }
    
    // Tạo bảng với các cột và ràng buộc cần thiết
    $createTableQuery = "CREATE TABLE IF NOT EXISTS user_logs (
        id INTEGER PRIMARY KEY AUTOINCREMENT,
        CreatedDate DATETIME DEFAULT CURRENT_TIMESTAMP,
        Name TEXT,
        BirthDate TEXT,
        uPhone TEXT NOT NULL,
        uEmail TEXT NOT NULL,
        device_id TEXT NOT NULL,
        count INTEGER NOT NULL DEFAULT 0,
        approved INTEGER NOT NULL DEFAULT 0,
        last_access TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
        UserData TEXT,
        Note TEXT
    )";

    // Thực thi câu truy vấn tạo bảng
    if (!$db->exec($createTableQuery)) {
        die("Lỗi khi tạo bảng: " . $db->lastErrorMsg());
    }

    // Tạo chỉ mục để cải thiện hiệu suất truy vấn
    $db->exec("CREATE INDEX IF NOT EXISTS idx_uPhone ON user_logs (uPhone)");
    $db->exec("CREATE INDEX IF NOT EXISTS idx_uEmail ON user_logs (uEmail)");
    $db->exec("CREATE INDEX IF NOT EXISTS idx_device_id ON user_logs (device_id)");
    
    return $db;
}

// Khởi tạo cơ sở dữ liệu
// $db = initializeDatabase();
?>


<?php
// Khởi tạo cơ sở dữ liệu
$db = initializeDatabase();

// Hàm lấy mã định danh thiết bị
function getDeviceId() {
    if (!isset($_COOKIE['device_id'])) {
        $deviceId = uniqid('', true);
        setcookie('device_id', $deviceId, time() + (10 * 365 * 24 * 60 * 60), "/");
    } else {
        $deviceId = $_COOKIE['device_id'];
    }
    return $deviceId;
}

// Lấy thông tin từ cookie
$uPhone = @$_COOKIE["uPhone"];
$uEmail = @$_COOKIE["uEmail"];
$deviceId = getDeviceId();
// echo "<script> alert('$uPhone-$uEmail-$deviceId ');</script>";
// die();
// Hàm ghi nhận và kiểm tra lần truy cập của người dùng
function logUserAccess($db, $uPhone, $uEmail, $deviceId, $uname, $BirthDate) {
    if( is_null($uPhone)){
        return -1;
    }
    $stmt = $db->prepare("SELECT * FROM user_logs WHERE uPhone = :uPhone AND uEmail = :uEmail AND device_id = :device_id");
    $stmt->bindValue(':uPhone', $uPhone, SQLITE3_TEXT);
    $stmt->bindValue(':uEmail', $uEmail, SQLITE3_TEXT);
    $stmt->bindValue(':device_id', $deviceId, SQLITE3_TEXT);
    $result = $stmt->execute();

    if ($data = $result->fetchArray(SQLITE3_ASSOC)) {
        $count = $data['count'] + 1;
        $stmt = $db->prepare("UPDATE user_logs SET count = :count, last_access = CURRENT_TIMESTAMP WHERE id = :id");
        $stmt->bindValue(':count', $count, SQLITE3_INTEGER);
        $stmt->bindValue(':id', $data['id'], SQLITE3_INTEGER);
        $stmt->execute();
    } else {
        $count = 1;
        $stmt = $db->prepare("INSERT INTO user_logs (uPhone, Name, BirthDate, uEmail, device_id, count) VALUES (:uPhone, :Name, :BirthDate, :uEmail, :device_id, :count)");
        $stmt->bindValue(':Name',  $uname, SQLITE3_TEXT);
        $stmt->bindValue(':BirthDate', $BirthDate, SQLITE3_TEXT);
        $stmt->bindValue(':uPhone', $uPhone, SQLITE3_TEXT);
        $stmt->bindValue(':uEmail', $uEmail, SQLITE3_TEXT);
        $stmt->bindValue(':device_id', $deviceId, SQLITE3_TEXT);
        $stmt->bindValue(':count', $count, SQLITE3_INTEGER);
        $stmt->execute();
    }

    return $count;
}

// Hàm kiểm tra số thiết bị sử dụng cùng một tài khoản
function checkMultipleDevices($db, $uPhone, $uEmail) {
    $stmt = $db->prepare("SELECT COUNT(DISTINCT device_id) AS device_count FROM user_logs WHERE uPhone = :uPhone AND uEmail = :uEmail");
    $stmt->bindValue(':uPhone', $uPhone, SQLITE3_TEXT);
    $stmt->bindValue(':uEmail', $uEmail, SQLITE3_TEXT);
    $result = $stmt->execute();
    $data = $result->fetchArray(SQLITE3_ASSOC);
    return $data['device_count'];
}

// Kiểm tra thiết bị đã được phê duyệt
function isDeviceApproved($db, $uPhone, $uEmail, $deviceId) {
    $stmt = $db->prepare("SELECT approved FROM user_logs WHERE uPhone = :uPhone AND uEmail = :uEmail AND device_id = :device_id");
    $stmt->bindValue(':uPhone', $uPhone, SQLITE3_TEXT);
    $stmt->bindValue(':uEmail', $uEmail, SQLITE3_TEXT);
    $stmt->bindValue(':device_id', $deviceId, SQLITE3_TEXT);
    $result = $stmt->execute();
    $data = $result->fetchArray(SQLITE3_ASSOC);
    if ($data){
        return $data['approved'] == 1;
    }else{
        return false;
    }
}

// // Ghi nhận lần truy cập của người dùng
// $count = logUserAccess($db, $uPhone, $uEmail, $deviceId);

// // Kiểm tra số thiết bị sử dụng cùng một tài khoản
// $deviceCount = checkMultipleDevices($db, $uPhone, $uEmail);

// // Nếu thiết bị không được phê duyệt, hiển thị cảnh báo và ngăn truy cập
// if (!isDeviceApproved($db, $uPhone, $uEmail, $deviceId)) {
//     echo "<script>alert('Thiết bị của bạn chưa được phê duyệt để sử dụng tài khoản này.');</script>";
//     exit;
// }

// // Hiện cảnh báo nếu có nhiều thiết bị sử dụng chung tài khoản
// if ($deviceCount > 3) {
//     echo "<script>alert('Cảnh báo: Tài khoản này đang được sử dụng bởi nhiều thiết bị.');</script>";
//     if ($count > 30) {
//         echo "<script>alert('Bạn đã sử dụng chung tài khoản quá nhiều lần và bị chặn sử dụng trang web.');</script>";
//         exit; // Ngăn không cho tiếp tục truy cập trang web
//     }
// }
?>

