<?php
function processVideoLink($videoLink)
{
    // Kiểm tra nếu là iframe HTML
    if (stripos($videoLink, 'iframe') !== false) {
        // Nếu chuỗi đã là iframe, giữ nguyên
        return $videoLink;
    }

    // Kiểm tra nếu là link YouTube hoặc video ID
    $youtubeEmbedBase = "https://www.youtube.com/embed/";
    $urlParts = parse_url($videoLink);

    if (isset($urlParts['host']) && (strpos($urlParts['host'], 'youtube') !== false || strpos($urlParts['host'], 'youtu') !== false)) {
        // Nếu là một URL đầy đủ của YouTube
        if (strpos($urlParts['host'], 'youtube.com') !== false) {
            parse_str($urlParts['query'], $queryParams);
            if (isset($queryParams['v'])) {
                return htmlspecialchars(sprintf(
                    '<iframe src="%s%s" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>',
                    $youtubeEmbedBase,
                    htmlspecialchars($queryParams['v'])
                ));
            }
        }

        // Nếu là URL rút gọn YouTube (youtu.be)
        if (strpos($urlParts['host'], 'youtu.be') !== false) {
            $videoId = ltrim($urlParts['path'], '/');
            return htmlspecialchars(sprintf(
                '<iframe src="%s%s" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>',
                $youtubeEmbedBase,
                htmlspecialchars($videoId)
            ));
        }
    }
    elseif (preg_match('/^[a-zA-Z0-9_-]{11}$/', $videoLink)) {
        // Nếu là YouTube Video ID
        return htmlspecialchars(sprintf(
            '<iframe src="%s%s" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" referrerpolicy="strict-origin-when-cross-origin" allowfullscreen></iframe>',
            $youtubeEmbedBase,
            htmlspecialchars($videoLink)
        ));
    }

    // Nếu không khớp, trả về giá trị gốc
    return htmlspecialchars($videoLink);
}

// Sử dụng hàm trong HTML:
// $videoEmbed = processVideoLink($course['video_link']);



function _vn2en($str)
{
    $unicode = array(
        'a' => 'á|à|ả|ã|ạ|ă|ắ|ặ|ằ|ẳ|ẵ|â|ấ|ầ|ẩ|ẫ|ậ',
        'd' => 'đ',
        'e' => 'é|è|ẻ|ẽ|ẹ|ê|ế|ề|ể|ễ|ệ',
        'i' => 'í|ì|ỉ|ĩ|ị',
        'o' => 'ó|ò|ỏ|õ|ọ|ô|ố|ồ|ổ|ỗ|ộ|ơ|ớ|ờ|ở|ỡ|ợ',
        'u' => 'ú|ù|ủ|ũ|ụ|ư|ứ|ừ|ử|ữ|ự',
        'y' => 'ý|ỳ|ỷ|ỹ|ỵ',
        'A' => 'Á|À|Ả|Ã|Ạ|Ă|Ắ|Ặ|Ằ|Ằ|Ẵ|Â|Ấ|Ầ|Ẩ|Ẫ|Ậ',
        'D' => 'Đ',
        'E' => 'É|È|Ẻ|Ẽ|Ẹ|Ê|Ế|Ề|Ể|Ễ|Ệ',
        'I' => 'Í|Ì|Ỉ|Ĩ|Ị',
        'O' => 'Ó|Ò|Ỏ|Õ|Ọ|Ô|Ố|Ồ|Ổ|Ỗ|Ộ|Ơ|Ớ|Ờ|Ở|Ỡ|Ợ',
        'U' => 'Ú|Ù|Ủ|Ũ|Ụ|Ư|Ứ|Ừ|Ử|Ữ|Ự',
        'Y' => 'Ý|Ỳ|Ỷ|Ỹ|Ỵ',
    );
    foreach ($unicode as $nonUnicode => $uni) {
        $str = preg_replace("/($uni)/",
            $nonUnicode,
            $str
        );
    }

    return $str;
}
// echo _vn2en('Xin chào!');

  
function sanitize_for_url($string) {
    // Chuyển đổi chuỗi sang chữ thường
    $string = strtolower($string);
    
    // Thay thế các ký tự đặc biệt và nhiều dấu cách thành một dấu gạch ngang
    $string = preg_replace('/[^a-z0-9\s]/', '', $string); // Loại bỏ các ký tự đặc biệt, giữ lại khoảng trắng
    $string = preg_replace('/\s+/', ' ', $string); // Loại bỏ nhiều khoảng trắng liền kề
    $string = preg_replace('/\s/', '-', $string); // Thay thế khoảng trắng bằng dấu gạch ngang
    
    return $string;
}

// // Sử dụng hàm
// $original_string = "Chào! Đây là ví dụ cho hàm tạo đường dẫn!";
// $sanitized_string = sanitize_for_url($original_string);

// echo $sanitized_string; // Output: chao-day-la-vi-du-cho-ham-tao-duong-dan
 
 
 
function ChuanHoaXau_thanh_path($string){
    return sanitize_for_url(_vn2en($string));
}


 
function resizeAndMoveImage($file, $imageName = '', $destinationDir = 'images/',  $newWidth = 400, $newHeight = 225) {
    // Kiểm tra xem file có được tải lên thành công không
    if ($file['error'] != UPLOAD_ERR_OK) {
        return 'Lỗi khi tải file lên.';
    }
    if (!file_exists($destinationDir)) {
        // Tạo thư mục với quyền 0755 (chỉ định quyền truy cập)
        if (mkdir($destinationDir, 0755, true)) { 
        }  
    }
    // Lấy tên và tạm thời tên file tải lên
    $imageTempName = $file['tmp_name'];
    

    // Kiểm tra định dạng của ảnh
    $imageInfo = getimagesize($imageTempName);
    if ($imageInfo === false) {
        return 'Không phải định dạng hình ảnh hợp lệ.';
    }

    // Tạo đối tượng hình ảnh từ file tải lên
    switch ($imageInfo[2]) {
        case IMAGETYPE_JPEG:
            $image = imagecreatefromjpeg($imageTempName); // enable extension=gd trong PHP.ini
            break;
        case IMAGETYPE_PNG:
            $image = imagecreatefrompng($imageTempName);
            break;
        case IMAGETYPE_GIF:
            $image = imagecreatefromgif($imageTempName);
            break;
        default:
            return 'Không hỗ trợ định dạng hình ảnh này.';
    }

    // Tạo một hình ảnh mới với kích thước resize
    $resizedImage = imagecreatetruecolor($newWidth, $newHeight);
    
    // Resize hình ảnh
    imagecopyresampled($resizedImage, $image, 0, 0, 0, 0, $newWidth, $newHeight, imagesx($image), imagesy($image));

    // Kiểm tra thư mục đích
    if (!is_dir($destinationDir)) {
        return 'Thư mục đích không tồn tại.';
    }

    // Lưu ảnh đã resize vào thư mục đích
    $destinationPath = $destinationDir . $imageName;
    imagejpeg($resizedImage, $destinationPath, 90); // Lưu ảnh JPEG với chất lượng 90%

    // Giải phóng bộ nhớ
    imagedestroy($image);
    imagedestroy($resizedImage);

    return $destinationPath; // Trả về đường dẫn file đã lưu
}
